<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sq">
<context>
    <name>notification::BubbleItem</name>
    <message>
        <source>just now</source>
        <translation>mu tani</translation>
    </message>
    <message>
        <source>1 new message</source>
        <translation>1 mesazh i ri</translation>
    </message>
</context>
<context>
    <name>notification::BubbleModel</name>
    <message>
        <source>%1 minutes ago</source>
        <translation>%1 minuta më parë</translation>
    </message>
</context>
</TS>